==> htcheck_1.1.orig.tar.gz: htcheck-1.1.orig/htcheck/Scheduler.h <==
///////
   //    Scheduler.h
   //    Scheduler Class declaration
   //
   //    Class for managing the crawling process
   //
   //    Part of the ht://Check package
   //
   //    Copyright (c) 1999-2002 Comune di Prato - Prato - Italy
   //    Some Portions Copyright (c) 1995-2000 The ht://Dig Group <www.htdig.org>
   //    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
   //
   //    For copyright details, see the file COPYING in your distribution
   //    or the GNU General Public License version 2 or later 
   //    <http://www.gnu.org/copyleft/gpl.html>
   //
   //    $Id: Scheduler.h,v 1.23 2002/02/06 11:04:34 angusgb Exp $
   //
   //    G.Bartolini
   //    started: 13.09.1999
///////

#ifndef _SCHEDULER_H
#define _SCHEDULER_H

#include <Object.h>
#include <HtmysqlDB.h>
#include <StringList.h>
#include <Dictionary.h>
#include <HtDateTime.h>
#include <Configuration.h>
#include <HtRegex.h>
#include <Transport.h>
#include <HtHTTPBasic.h>
#include "SchedulerEntry.h"
#include "_Url.h"
#include "_Server.h"
#include "RunInfo.h"

class HtmlParser;

class Scheduler : public Object
{

   // Declaring friend classes (parser classes)
   friend class HtmlParser;

   public:
   
      // Construction / Destruction
      Scheduler();
      virtual ~Scheduler();

      enum Scheduler_Query_Type
      {
         Scheduler_Stored,
         Scheduler_Direct
      };

      enum Scheduler_Codes
      {
         Scheduler_OK,
         Scheduler_MemoryError,
         Scheduler_DBError,
         Scheduler_Interrupted
      };

      enum Scheduler_URL_Validation
      {
         Scheduler_URL_Valid,
         Scheduler_URL_MaxHopCount,
         Scheduler_URL_Excludes,
         Scheduler_URL_BadQueryString,
         Scheduler_URL_BadExtension,
         Scheduler_URL_NotValidExtension,
         Scheduler_URL_OutOfLimits,
         Scheduler_URL_FileProtocol,
         Scheduler_URL_EMail,
         Scheduler_URL_Javascript,
         Scheduler_URL_NotValidService,
         Scheduler_URL_Malformed
      };

///////
   //    Database Selection
///////

      Scheduler_Codes SelectDatabase(const String &name);


///////
   //    Restoring info from Database
///////

      Scheduler_Codes RestoreDatabase();


///////
   //    Set-up and Initialization
///////

      void SetOptions(Configuration &config);   // Set the options
      int Initial(const String &list);          // Initialize the URL list
      void SetArgumentList(int *_argc, char *** _argv)
         { argc = _argc; argv = _argv;}

///////
   //    Running process
///////

      Scheduler_Codes Run();
      void Stop() { stop = 1;}


///////
   //    Show info at the end of the crawl
///////

      Scheduler_Codes ShowStatusCode(ostream &output = std::cout);
      Scheduler_Codes ShowBrokenLinks(ostream &output = std::cout);
      Scheduler_Codes ShowAnchorNotFound(ostream &output = std::cout);
      //Scheduler_Codes ShowContentTypes(ostream &output = std::cout);
      Scheduler_Codes ShowContentTypesPerServer(ostream &output = std::cout);

      
///////
   //    Public access to protected attributes
///////

      Scheduler_URL_Validation IsAValidURL(const SchedulerEntry &);

      HtmysqlDB *GetDB() { return DB; }
      const HtDateTime *GetStartTime() { return &runinfo.StartTime; }
      const HtDateTime *GetFinishTime() { return &runinfo.FinishTime; }
      const int GetRunningTime() {
         return HtDateTime::GetDiff(runinfo.FinishTime, runinfo.StartTime); }
      void SetFinishTime() { runinfo.FinishTime.SettoNow(); }
      
      void SetDebugLevel(int d) { debug = d; }
      int GetDebugLevel() { return debug; }
      void SetStatsLevel(int l) { stats = l; }
      void SetInitializationLevel(int l) { erase = l; }
      const int GetInitializationLevel() const { return erase; }
      void SetUserAgent(const String &ua);


   protected:

///////
   //    Protected Methods
///////


 ///////
    //    Retrieve a URL
 ///////

      Transport::DocStatus Retrieve (const SchedulerEntry &s, _Url &url);


 ///////
    //   Add a URL or find an existant in the DB
    //   If OK, stores the new or found ID value into IDUrl
    //   If previous is set to true, CurrentSchedule is considered
    //   as it was the calling URL (so used for the referer setting
    //   and the hop count too). If previous is set to false, we don't
    //   set them, just think for example at the starting URL list.
 ///////

      Scheduler_Codes AddUrl(const String &u, unsigned int &IDUrl,
         bool previous=true);


 ///////
    //    Add a new server
 ///////

      _Server *AddServer(_Url &u);
      _Server *FindServer(const String &signature);


 ///////
    //    Search the Scheduler
 ///////

      int GetNext();
      int GetNext(const String &StrStatus);


 ///////
    //   Depending ont the Link table values (considering only those
    //   records with a LinkType='Direct') this method calculates the
    //   added size to the URL. That is to say: it adds sizes of the direct
    //   linked URLs (only once per document), those that are loaded
    //   automatically by the user agent together with the page (ex.: images).
 ///////

      Scheduler_Codes CalculateUrlSizeAdd();


 ///////
    //    Set the Link results (at the end of the crawl)
    //    Look for all the links that have 'NotChecked' flag in the LinkResult
    //    field. For each of them, it checks all of the links, and see if
    //    they are eithrt found or not retrieved or broken or redirected.
    //    Then it updates the Link table with the right flag.
 ///////

      Scheduler_Codes SetLinkResults(ostream &output = std::cout);


 ///////
    //    Check the HTML anchors
 ///////

      Scheduler_Codes SetHTMLAnchorsResults(ostream &output = std::cout);


 ///////
    //    Deserialize the memory dictionary
 ///////

      Scheduler_Codes DeserializeServers(); // about servers
      Scheduler_Codes DeserializeCookies(); // about servers


 ///////
    //    Tell us if we should retry to retrieve an URL depending on
    //    the first returned document status
 ///////

      int ShouldWeRetry(Transport::DocStatus DocumentStatus);


 ////////
   //     Check for the Proxy
 ///////

      bool UseProxy(const SchedulerEntry &);
      
///////
   //    Protected attributes
///////

      HtmysqlDB      *DB;                    // Database Pointer
      Dictionary     servers;                // Servers
   
      SchedulerEntry  CurrentSchedule;       // CurrentSchedule retrieved
      SchedulerEntry  CurrentLinkSchedule;   // Current Link schedule
      SchedulerEntry  Referer;               // Referer

      _Server  *CurrentServer;               // Current server queried
      _Url     *CurrentUrl;                  // Current Url
      _Url     *Proxy;                       // Proxy Url
      String   Credentials;                  // Credentials string
      String   AcceptLanguage;               // HTTP accept-language directive
      
      // Temporary results for querying the Schedule database table
      HtmysqlQueryResult   ScheduleTmp;
      
      // Transport Pointers
      Transport            *TransportConnect;
      HtHTTP               *HTTPConnect;
      Transport_Response   *CurrentResponse;


      int erase;  // Erase the DB?
      int stop;   // Catch the signals
      bool deserialized;   // Boolean for deserialization of servers
      bool deserialized_cookies; // Boolean for deserialization of cookies

      HtCookieJar *_cookie_jar;  // Cookie jar manager object   
      RunInfo     runinfo;      // Run time Info

      // Execution info
      int *argc;
      char ***argv;
      String options_list;

///////
   //    Configuration variables
///////

      Configuration  *Config;          // Pointer to the configuration
      
      HtRegex     Limits;              // URL limits
      HtRegex     LimitsNormalized;    // URL limits (normalized)
      HtRegex     Excludes;            // URL exclusions
      HtRegex     BadQueryString;      // Bad query string
      HtRegex     ExcludeProxy;        // URLs to be excluded from the proxy
      
      Dictionary  ValidExtensions;    // Extensions to be included
      Dictionary  BadExtensions;      // Extensions to be excluded

      int debug;  // Debug info
      int stats;  // Statistics available?
};

#endif

==> htcheck_1.2.4~rc1.orig.tar.gz: htcheck-1.2.4-rc1/htcheck/Scheduler.h <==
///////
   //    Scheduler.h
   //    Scheduler Class declaration
   //
   //    Class for managing the crawling process
   //
   //    Part of the ht://Check package
   //
   //    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
   //    Some Portions Copyright (c) 1995-2000 The ht://Dig Group <www.htdig.org>
   //    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
   //
   //    For copyright details, see the file COPYING in your distribution
   //    or the GNU General Public License version 2 or later 
   //    <http://www.gnu.org/copyleft/gpl.html>
   //
   //    $Id: Scheduler.h,v 1.28 2003/12/30 09:38:47 angusgb Exp $
   //
   //    G.Bartolini
   //    started: 13.09.1999
///////

#ifndef _SCHEDULER_H
#define _SCHEDULER_H

#include <Object.h>
#include <HtmysqlDB.h>
#include <StringList.h>
#include <Dictionary.h>
#include <HtDateTime.h>
#include <Configuration.h>
#include <HtRegex.h>
#include <Transport.h>
#include <HtHTTPBasic.h>
#include "SchedulerEntry.h"
#include "_Url.h"
#include "_Server.h"
#include "RunInfo.h"

class HtmlParser;

class Scheduler : public Object
{

   // Declaring friend classes (parser classes)
   friend class HtmlParser;

   public:
   
      // Construction / Destruction
      Scheduler();
      virtual ~Scheduler();

      enum Scheduler_Query_Type
      {
         Scheduler_Stored,
         Scheduler_Direct
      };

      enum Scheduler_Codes
      {
         Scheduler_OK,
         Scheduler_MemoryError,
         Scheduler_DBError,
         Scheduler_Interrupted
      };

      enum Scheduler_URL_Validation
      {
         Scheduler_URL_Valid,
         Scheduler_URL_MaxHopCount,
         Scheduler_URL_Excludes,
         Scheduler_URL_BadQueryString,
         Scheduler_URL_BadExtension,
         Scheduler_URL_NotValidExtension,
         Scheduler_URL_OutOfLimits,
         Scheduler_URL_FileProtocol,
         Scheduler_URL_EMail,
         Scheduler_URL_Javascript,
         Scheduler_URL_NotValidService,
         Scheduler_URL_Malformed
      };

///////
   //    Database Selection
///////

      Scheduler_Codes SelectDatabase(const String &name);


///////
   //    Restoring info from Database
///////

      Scheduler_Codes RestoreDatabase();


///////
   //    Set-up and Initialization
///////

      void SetOptions(Configuration &config);   // Set the options
      int Initial(const String &list);          // Initialize the URL list
      void SetArgumentList(int *_argc, char *** _argv)
         { argc = _argc; argv = _argv;}

///////
   //    Running process
///////

      Scheduler_Codes Run();
      void Stop() { stop = 1;}


///////
   //    Show info at the end of the crawl
///////

      Scheduler_Codes ShowStatusCode(ostream &output = std::cout);
      Scheduler_Codes ShowBrokenLinks(ostream &output = std::cout);
      Scheduler_Codes ShowAnchorNotFound(ostream &output = std::cout);
      //Scheduler_Codes ShowContentTypes(ostream &output = std::cout);
      Scheduler_Codes ShowContentTypesPerServer(ostream &output = std::cout);

      
///////
   //    Public access to protected attributes
///////

      Scheduler_URL_Validation IsAValidURL(const SchedulerEntry &);

      HtmysqlDB *GetDB() { return DB; }
      const HtDateTime *GetStartTime() { return &runinfo.StartTime; }
      const HtDateTime *GetFinishTime() { return &runinfo.FinishTime; }
      const int GetRunningTime() {
         return HtDateTime::GetDiff(runinfo.FinishTime, runinfo.StartTime); }
      void SetFinishTime() { runinfo.FinishTime.SettoNow(); }
      
      void SetDebugLevel(int d) { debug = d; }
      int GetDebugLevel() { return debug; }
	  void SetDropDatabase(const bool f) { drop_database = f; }
	  bool GetDropDatabase() const { return drop_database; }
      void SetStatsLevel(int l) { stats = l; }
      void SetInitializationLevel(int l) { erase = l; }
      const int GetInitializationLevel() const { return erase; }
      void SetUserAgent(const String &ua);


   protected:

///////
   //    Protected Methods
///////


 ///////
    //    Retrieve a URL
 ///////

      Transport::DocStatus Retrieve (const SchedulerEntry &s, _Url &url);


 ///////
    //   Add a URL or find an existant in the DB
    //   If OK, stores the new or found ID value into IDUrl
    //   If previous is set to true, CurrentSchedule is considered
    //   as it was the calling URL (so used for the referer setting
    //   and the hop count too). If previous is set to false, we don't
    //   set them, just think for example at the starting URL list.
 ///////

      Scheduler_Codes AddUrl(const String &u, unsigned int &IDUrl,
         bool previous=true);


 ///////
    //    Add a new server
 ///////

      _Server *AddServer(_Url &u);
      _Server *FindServer(const String &signature);


 ///////
    //    Search the Scheduler
 ///////

      int GetNext();
      int GetNext(const String &StrStatus);


 ///////
    //   Depending ont the Link table values (considering only those
    //   records with a LinkType='Direct') this method calculates the
    //   added size to the URL. That is to say: it adds sizes of the direct
    //   linked URLs (only once per document), those that are loaded
    //   automatically by the user agent together with the page (ex.: images).
 ///////

      Scheduler_Codes CalculateUrlSizeAdd();

 ///////
    //    Check the HTML anchors
 ///////

      Scheduler_Codes SetHTMLAnchorsResults(ostream &output = std::cout);


 ///////
    //    Deserialize the memory dictionary
 ///////

      Scheduler_Codes DeserializeServers(); // about servers
      Scheduler_Codes DeserializeCookies(); // about servers


 ///////
    //    Tell us if we should retry to retrieve an URL depending on
    //    the first returned document status
 ///////

      int ShouldWeRetry(Transport::DocStatus DocumentStatus);


 ////////
   //     Check for the Proxy
 ///////

      bool UseProxy(const SchedulerEntry &);
      
///////
   //    Protected attributes
///////

      HtmysqlDB      *DB;                    // Database Pointer
      Dictionary     servers;                // Servers
   
      SchedulerEntry  CurrentSchedule;       // CurrentSchedule retrieved
      SchedulerEntry  CurrentLinkSchedule;   // Current Link schedule
      SchedulerEntry  Referer;               // Referer

      _Server  *CurrentServer;               // Current server queried
      _Url     *CurrentUrl;                  // Current Url
      _Url     *Proxy;                       // Proxy Url
      String   Credentials;                  // Credentials string
      String   ProxyCredentials;             // Proxy Credentials string
      String   AcceptLanguage;               // HTTP accept-language directive
      
      // Temporary results for querying the Schedule database table
      HtmysqlQueryResult   ScheduleTmp;
      
      // Transport Pointers
      Transport            *TransportConnect;
      HtHTTP               *HTTPConnect;
      Transport_Response   *CurrentResponse;


      int erase;  // Erase the DB?
      int stop;   // Catch the signals
      bool drop_database;  // Erase the DB - without dropping the database
      bool deserialized;   // Boolean for deserialization of servers
      bool deserialized_cookies; // Boolean for deserialization of cookies

      HtCookieJar *_cookie_jar;  // Cookie jar manager object   
      RunInfo     runinfo;      // Run time Info

      // Execution info
      int *argc;
      char ***argv;
      String options_list;

///////
   //    Configuration variables
///////

      Configuration  *Config;          // Pointer to the configuration
      
      HtRegex     Limits;              // URL limits
      HtRegex     LimitsNormalized;    // URL limits (normalized)
      HtRegex     Excludes;            // URL exclusions
      HtRegex     BadQueryString;      // Bad query string
      HtRegex     ExcludeProxy;        // URLs to be excluded from the proxy
      
      Dictionary  ValidExtensions;    // Extensions to be included
      Dictionary  BadExtensions;      // Extensions to be excluded

      int debug;  // Debug info
      int stats;  // Statistics available?
};

#endif
